Struct Animation
pub struct Animation<T>{ /* private fields */ }Expand description
The animation of some particular state.
It tracks state changes and allows projecting interpolated values through time.
Implementations
impl<T> Animation<T>
impl<T> Animation<T>
pub fn easing(self, easing: Easing) -> Animation<T>
pub fn easing(self, easing: Easing) -> Animation<T>
Sets the Easing function of the Animation.
See the Easing Functions Cheat Sheet for details!
pub fn very_quick(self) -> Animation<T>
pub fn very_quick(self) -> Animation<T>
Sets the duration of the Animation to 100ms.
pub fn duration(self, duration: Duration) -> Animation<T>
pub fn duration(self, duration: Duration) -> Animation<T>
Sets the duration of the Animation to the given value.
pub fn repeat(self, repetitions: u32) -> Animation<T>
pub fn repeat(self, repetitions: u32) -> Animation<T>
Makes the Animation repeat a given amount of times.
Providing 1 repetition plays the animation twice in total.
pub fn repeat_forever(self) -> Animation<T>
pub fn repeat_forever(self) -> Animation<T>
Makes the Animation repeat forever.
pub fn auto_reverse(self) -> Animation<T>
pub fn auto_reverse(self) -> Animation<T>
Makes the Animation automatically reverse when repeating.
pub fn go(self, new_state: T, at: Instant) -> Animation<T>
pub fn go(self, new_state: T, at: Instant) -> Animation<T>
Transitions the Animation from its current state to the given new state
at the given time.
pub fn go_mut(&mut self, new_state: T, at: Instant)
pub fn go_mut(&mut self, new_state: T, at: Instant)
Transitions the Animation from its current state to the given new state
at the given time, by reference.
pub fn is_animating(&self, at: Instant) -> bool
pub fn is_animating(&self, at: Instant) -> bool
pub fn interpolate_with<I>(&self, f: impl Fn(T) -> I, at: Instant) -> Iwhere
I: Interpolable,
pub fn interpolate_with<I>(&self, f: impl Fn(T) -> I, at: Instant) -> Iwhere
I: Interpolable,
Projects the Animation into an interpolated value at the given Instant; using the
closure provided to calculate the different keyframes of interpolated values.
If the Animation state is a bool, you can use the simpler interpolate method.
impl Animation<bool>
impl Animation<bool>
pub fn interpolate<I>(&self, start: I, end: I, at: Instant) -> Iwhere
I: Interpolable + Clone,
pub fn interpolate<I>(&self, start: I, end: I, at: Instant) -> Iwhere
I: Interpolable + Clone,